import { markdownlintSentencesPerLine } from "./markdownlintSentencesPerLine.ts";
export default markdownlintSentencesPerLine;
export declare const description: string;
export declare const names: string[];
export declare const parser: "none";
export declare const tags: string[];
declare const ruleFunction: (params: import("markdownlint").RuleParams, onError: import("markdownlint").RuleOnError) => void;
export { ruleFunction as function };
//# sourceMappingURL=index.d.ts.map