import type * as markdownlint from "markdownlint";
export declare const markdownlintSentencesPerLine: {
    description: string;
    function: (params: markdownlint.RuleParams, onError: markdownlint.RuleOnError) => void;
    names: string[];
    parser: "none";
    tags: string[];
};
//# sourceMappingURL=markdownlintSentencesPerLine.d.ts.map