/** List of words to ignore when determining sentence boundaries */
export declare const ignoredWords: string[];
/**
 * Given a lint of text, determine if it ends with an ignored word.
 */
export declare const doesEndWithIgnoredWord: (input: string, customIgnoredWords?: string[]) => boolean;
//# sourceMappingURL=doesEndWithIgnoredWord.d.ts.map