export { doesEndWithIgnoredWord, ignoredWords, } from "./doesEndWithIgnoredWord.ts";
export { getIndexBeforeSecondSentence } from "./getIndexBeforeSecondSentence.ts";
declare const _default: () => never;
export default _default;
//# sourceMappingURL=index.d.ts.map