/**
 * @returns The first index after the period, question mark, or exclamation mark of the line's first sentence,
 * if a second sentence follows it.
 */
export declare function getIndexBeforeSecondSentence(line: string): number | undefined;
//# sourceMappingURL=getIndexBeforeSecondSentence.d.ts.map