export { doesEndWithIgnoredWord, ignoredWords, } from "./doesEndWithIgnoredWord.js";
export { getIndexBeforeSecondSentence } from "./getIndexBeforeSecondSentence.js";
export default () => {
    throw new Error("The Markdownlint sentences-per-line plugin is now in the dedicated markdownlint-sentences-per-line package.");
};
//# sourceMappingURL=index.js.map