import type {CharacterMetricsTuple, FontName} from "./types/fonts";

type FontMetrics = Record<number, CharacterMetricsTuple>;

declare const fontMetricsData: Record<FontName, FontMetrics> &
    Record<string, FontMetrics>;

export default fontMetricsData;
